Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.PersonGruppeSchlank Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.PersonGruppeSchlank einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.PersonGruppeSchlank) | Gemeinde_Modelle.PersonGruppeSchlank |
__str__(self) (Definiert in Gemeinde_Modelle.PersonGruppeSchlank) | Gemeinde_Modelle.PersonGruppeSchlank |
keyFeldNavi (Definiert in Gemeinde_Modelle.PersonGruppeSchlank) | Gemeinde_Modelle.PersonGruppeSchlank | static
R_gruppe (Definiert in Gemeinde_Modelle.PersonGruppeSchlank) | Gemeinde_Modelle.PersonGruppeSchlank | static
R_person (Definiert in Gemeinde_Modelle.PersonGruppeSchlank) | Gemeinde_Modelle.PersonGruppeSchlank | static